[asterisk-commits] trunk r33174 - in /trunk: apps/app_dial.c include/asterisk/rtp.h rtp.c

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Fri Jun 9 02:47:44 MST 2006


Author: oej
Date: Fri Jun  9 04:47:44 2006
New Revision: 33174

URL: http://svn.digium.com/view/asterisk?rev=33174&view=rev
Log:
Rename ast_rtp_early_media to ast_rtp_early_bridge to avoid confusion.

Modified:
    trunk/apps/app_dial.c
    trunk/include/asterisk/rtp.h
    trunk/rtp.c

Modified: trunk/apps/app_dial.c
URL: http://svn.digium.com/view/asterisk/trunk/apps/app_dial.c?rev=33174&r1=33173&r2=33174&view=diff
==============================================================================
--- trunk/include/asterisk/rtp.h (original)
+++ trunk/include/asterisk/rtp.h Fri Jun  9 04:47:44 2006
@@ -182,7 +182,9 @@
 
 int ast_rtp_make_compatible(struct ast_channel *dest, struct ast_channel *src, int media);
 
-int ast_rtp_early_media(struct ast_channel *dest, struct ast_channel *src);
+/*! \brief If possible, create an early bridge directly between the devices without
+           having to send a re-invite later */
+int ast_rtp_early_bridge(struct ast_channel *dest, struct ast_channel *src);
 
 void ast_rtp_stop(struct ast_rtp *rtp);
 

Modified: trunk/rtp.c
URL: http://svn.digium.com/view/asterisk/trunk/rtp.c?rev=33174&r1=33173&r2=33174&view=diff
==============================================================================
--- trunk/rtp.c (original)
+++ trunk/rtp.c Fri Jun  9 04:47:44 2006
@@ -1274,7 +1274,7 @@
 	return cur;
 }
 
-int ast_rtp_early_media(struct ast_channel *dest, struct ast_channel *src)
+int ast_rtp_early_bridge(struct ast_channel *dest, struct ast_channel *src)
 {
 	struct ast_rtp *destp, *srcp=NULL;		/* Audio RTP Channels */
 	struct ast_rtp *vdestp, *vsrcp=NULL;		/* Video RTP channels */



More information about the asterisk-commits mailing list
--- trunk/apps/app_dial.c (original)
+++ trunk/apps/app_dial.c Fri Jun  9 04:47:44 2006
@@ -576,8 +576,8 @@
 							       OPT_CALLEE_MONITOR | OPT_CALLER_MONITOR |
 							       OPT_CALLEE_PARK | OPT_CALLER_PARK |
 							       DIAL_NOFORWARDHTML);
-						/* Setup early media if appropriate */
-						ast_rtp_early_media(in, peer);
+						/* Setup RTP early bridge if appropriate */
+						ast_rtp_early_bridge(in, peer);
 					}
 					/* If call has been answered, then the eventual hangup is likely to be normal hangup */
 					in->hangupcause = AST_CAUSE_NORMAL_CLEARING;
@@ -606,7 +606,7 @@
 						ast_verbose(VERBOSE_PREFIX_3 "%s is ringing\n", c->name);
 					/* Setup early media if appropriate */
 					if (single)
-						ast_rtp_early_media(in, c);
+						ast_rtp_early_bridge(in, c);
 					if (!(*sentringing) && !ast_test_flag(outgoing, OPT_MUSICBACK)) {
 						ast_indicate(in, AST_CONTROL_RINGING);
 						(*sentringing)++;
@@ -617,7 +617,7 @@
 						ast_verbose (VERBOSE_PREFIX_3 "%s is making progress passing it to %s\n", c->name, in->name);
 					/* Setup early media if appropriate */
 					if (single)
-						ast_rtp_early_media(in, c);
+						ast_rtp_early_bridge(in, c);
 					if (!ast_test_flag(outgoing, OPT_RINGBACK))
 						ast_indicate(in, AST_CONTROL_PROGRESS);
 					break;
@@ -630,7 +630,7 @@
 					if (option_verbose > 2)
 						ast_verbose (VERBOSE_PREFIX_3 "%s is proceeding passing it to %s\n", c->name, in->name);
 					if (single)
-						ast_rtp_early_media(in, c);
+						ast_rtp_early_bridge(in, c);
 					if (!ast_test_flag(outgoing, OPT_RINGBACK))
 						ast_indicate(in, AST_CONTROL_PROCEEDING);
 					break;
@@ -1608,7 +1608,7 @@
 		sentringing = 0;
 		ast_indicate(chan, -1);
 	}
-	ast_rtp_early_media(chan, NULL);
+	ast_rtp_early_bridge(chan, NULL);
 	hanguptree(outgoing, NULL);
 	pbx_builtin_setvar_helper(chan, "DIALSTATUS", status);
 	if (option_debug)

Modified: trunk/include/asterisk/rtp.h
URL: http://svn.digium.com/view/asterisk/trunk/include/asterisk/rtp.h?rev=33174&r1=33173&r2=33174&view=diff
==============================================================================